Index: trunk/MagicSoft/Mars/mcalib/MHCalibrationChargeBlindPix.cc
===================================================================
--- trunk/MagicSoft/Mars/mcalib/MHCalibrationChargeBlindPix.cc	(revision 3941)
+++ trunk/MagicSoft/Mars/mcalib/MHCalibrationChargeBlindPix.cc	(revision 3952)
@@ -120,4 +120,7 @@
 // Initializes:
 // - all pointers to NULL
+// - fASinglePheFADCSlices(0);
+// - fAPedestalFADCSlices(0);
+//
 //
 // Calls:
@@ -148,4 +151,7 @@
     fHGausHist.SetYTitle("Nr. of events");
 
+    fASinglePheFADCSlices(0);
+    fAPedestalFADCSlices(0);
+  
     Clear();
 }
@@ -294,8 +300,4 @@
 // - MExtractedSignalBlindPixel
 // 
-// Initializes:
-// - fASinglePheFADCSlices(0);
-// - fAPedestalFADCSlices(0);
-//
 // Calls:
 // - MHGausHist::InitBins()
@@ -317,7 +319,4 @@
       return kFALSE;
     }
-  
-  fASinglePheFADCSlices(0);
-  fAPedestalFADCSlices(0);
   
   InitBins();
@@ -985,25 +984,32 @@
 
   pad->cd(3);
-  if (fHSinglePheFADCSlices)
-      delete fHSinglePheFADCSlices;
-
-  fHSinglePheFADCSlices = new TH1F(fASinglePheFADCSlices);
-  fHSinglePheFADCSlices->SetName("SinglePheFADCSlices");
-  fHSinglePheFADCSlices->SetTitle(Form("%s%f","Assumed Single Phe FADC Slices, Sum > ",fSinglePheCut));
-  fHSinglePheFADCSlices->SetXTitle("FADC slice number");
-  fHSinglePheFADCSlices->SetYTitle("FADC counts");
-  fHSinglePheFADCSlices->Draw(opt);
-
+
+  if (fASinglePheFADCSlices.GetNrows() != 0)
+    {
+      if (fHSinglePheFADCSlices)
+        delete fHSinglePheFADCSlices;
+      fHSinglePheFADCSlices = new TH1F(fASinglePheFADCSlices);
+      fHSinglePheFADCSlices->SetName("SinglePheFADCSlices");
+      fHSinglePheFADCSlices->SetTitle(Form("%s%f","Assumed Single Phe FADC Slices, Sum > ",fSinglePheCut));
+      fHSinglePheFADCSlices->SetXTitle("FADC slice number");
+      fHSinglePheFADCSlices->SetYTitle("FADC counts");
+      fHSinglePheFADCSlices->Draw(opt);
+    }
+  
   pad->cd(4);
-  if (fHPedestalFADCSlices)
-      delete fHPedestalFADCSlices;
-
-  fHPedestalFADCSlices = new TH1F(fAPedestalFADCSlices);
-  fHPedestalFADCSlices->SetName("PedestalFADCSlices");
-  fHPedestalFADCSlices->SetTitle(Form("%s%f","Pedestal FADC Slices, Sum < ",fSinglePheCut));
-  fHPedestalFADCSlices->SetXTitle("FADC slice number");
-  fHPedestalFADCSlices->SetYTitle("FADC counts");
-  fHPedestalFADCSlices->Draw(opt);
-
+  if (fAPedestalFADCSlices.GetNrows() != 0)
+    {
+
+      if (fHPedestalFADCSlices)
+        delete fHPedestalFADCSlices;
+      
+      fHPedestalFADCSlices = new TH1F(fAPedestalFADCSlices);
+      fHPedestalFADCSlices->SetName("PedestalFADCSlices");
+      fHPedestalFADCSlices->SetTitle(Form("%s%f","Pedestal FADC Slices, Sum < ",fSinglePheCut));
+      fHPedestalFADCSlices->SetXTitle("FADC slice number");
+      fHPedestalFADCSlices->SetYTitle("FADC counts");
+      fHPedestalFADCSlices->Draw(opt);
+    }
+  
   if (win < 2)
   return;
Index: trunk/MagicSoft/Mars/mcalib/MHCalibrationChargeBlindPix.h
===================================================================
--- trunk/MagicSoft/Mars/mcalib/MHCalibrationChargeBlindPix.h	(revision 3941)
+++ trunk/MagicSoft/Mars/mcalib/MHCalibrationChargeBlindPix.h	(revision 3952)
@@ -46,5 +46,5 @@
   TVector fAPedestalFADCSlices;              // Averaged FADC slice entries supposed pedestal   events
  
-  TF1 *fSinglePheFit;                        //-> Single Phe Fit (Gaussians convoluted with Poisson) 
+  TF1 *fSinglePheFit;                        // Single Phe Fit (Gaussians convoluted with Poisson) 
 
   UInt_t  fNumSinglePhes;                    // Number of entries in fASinglePheFADCSlices

Index: trunk/MagicSoft/Mars/mcalib/MCalibrationRelTimeCalc.cc
===================================================================
--- trunk/MagicSoft/Mars/mcalib/MCalibrationRelTimeCalc.cc	(revision 3941)
+++ trunk/MagicSoft/Mars/mcalib/MCalibrationRelTimeCalc.cc	(revision 3952)
@@ -72,5 +72,5 @@
 using namespace std;
 
-const Float_t MCalibrationRelTimeCalc::fgRelTimeRelErrLimit      = 25.;
+const Float_t MCalibrationRelTimeCalc::fgRelTimeRelErrLimit      = 7.5;
 // --------------------------------------------------------------------------
 //
@@ -292,7 +292,4 @@
         continue;
 
-      if (bad.IsUnsuitable(MBadPixelsPix::kUnreliableRun))
-        continue;
-      
       const Float_t res   = pix.GetTimePrecision();
       const Int_t   aidx  = (*fGeom)[i].GetAidx();
@@ -306,7 +303,7 @@
   for (UInt_t aidx=0; aidx<nareas; aidx++)
     {
-      if (numareavalid[aidx] == 0)
-        {
-          *fLog << warn << GetDescriptor() << ": No pixels with valid time resolution found "
+      if (numareavalid[aidx] < 20)
+        {
+          *fLog << warn << GetDescriptor() << ": Less than 20 pixels with valid time resolution found "
                 << "in area index: " << aidx << endl;
           continue;